#[repr(u8)]pub enum Level {
Emerg = 0,
Alert = 1,
Crit = 2,
Error = 3,
Warning = 4,
Notice = 5,
Info = 6,
Debug = 7,
}Expand description
Kernel log level, matching the severity levels described in syslog(2).
Ordering
Levels are ordered by severity: Emerg < Alert < ... < Debug.
a < b means a is more severe than b.
Higher severity is assigned lower numeric value.
For example,
Level::Emerg has the smallest value of 0 and means the highest severity.
On the end of the spectrum,
Level::Debug has the largest value of 7 and means the lowest severity.
Mapping from Linux’s logging levels
The numeric values of Level::Xxx are assigned to those of their Linux counterparts.
LOGLEVEL_EMERG 0 /* system is unusable */
LOGLEVEL_ALERT 1 /* action must be taken immediately */
LOGLEVEL_CRIT 2 /* critical conditions */
LOGLEVEL_ERR 3 /* error conditions */
LOGLEVEL_WARNING 4 /* warning conditions */
LOGLEVEL_NOTICE 5 /* normal but significant condition */
LOGLEVEL_INFO 6 /* informational */
LOGLEVEL_DEBUG 7 /* debug-level messages */Mapping from the log crate
log::Level | ostd::log::Level | Notes |
|---|---|---|
| Error | Error (3) | |
| Warn | Warning (4) | |
| Info | Info (6) | |
| Debug | Debug (7) | |
| Trace | Debug (7) | Bridge only; no trace! macro in OSTD |
Variants
Emerg = 0
System is unusable.
Alert = 1
Action must be taken immediately.
Crit = 2
Critical conditions.
Error = 3
Error conditions.
Warning = 4
Warning conditions.
Notice = 5
Normal but significant condition.
Info = 6
Informational.
Debug = 7
Debug-level messages.
Implementations